@@ -8,7 +8,9 @@
 
 from dataclasses import dataclass
 
+from detector_connector import DetectorSettings
 
-@dataclass
-class ShiftSettings:
-    to_be_done: str = "to_be_done"
+
+@dataclass(kw_only=True, frozen=True)
+class ShiftSettings(DetectorSettings):
+    pass
